Crate tailcall_proc_macro

Crate tailcall_proc_macro 

This crate contains the procedural macro implementation for the https://crates.io/crates/tailcall crate. It is not designed to be used directly.

Macros

call
Marks an explicit stack-safe tail-call site inside a #[tailcall] function.

Attribute Macros

tailcall
Transforms a function definition so that explicit tail-call sites can execute without growing the call stack.